aboutsummaryrefslogtreecommitdiff
path: root/gdb/m68klinux-tdep.c
diff options
context:
space:
mode:
authorUlrich Weigand <uweigand@de.ibm.com>2007-10-11 19:35:29 +0000
committerUlrich Weigand <uweigand@de.ibm.com>2007-10-11 19:35:29 +0000
commite9efe249805e7b4942a21d8f7de79e6136eddefa (patch)
tree2d7c3fe0aa3abed4d25b2cd31cb6e002a4e27273 /gdb/m68klinux-tdep.c
parent7d00dcbd9cabb4e810e875fc821b1ed26f07c20f (diff)
downloadgdb-e9efe249805e7b4942a21d8f7de79e6136eddefa.zip
gdb-e9efe249805e7b4942a21d8f7de79e6136eddefa.tar.gz
gdb-e9efe249805e7b4942a21d8f7de79e6136eddefa.tar.bz2
* linux-nat.c (lin_lwp_attach_lwp): Use "Linux kernel 2.6.19"
instead of "Linux 2.6.19" in comment. (linux_xfer_partial): Use "GNU/Linux target" instead of "Linux target" in comment. * m68klinux-tdep.c (m68k_linux_inferior_created): Likewise. (m68k_linux_get_sigtramp_info): Likewise.
Diffstat (limited to 'gdb/m68klinux-tdep.c')
-rw-r--r--gdb/m68klinux-tdep.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/gdb/m68klinux-tdep.c b/gdb/m68klinux-tdep.c
index 8677a12..8270c5b 100644
--- a/gdb/m68klinux-tdep.c
+++ b/gdb/m68klinux-tdep.c
@@ -213,8 +213,8 @@ static int target_is_uclinux;
static void
m68k_linux_inferior_created (struct target_ops *objfile, int from_tty)
{
- /* Record that we will need to re-evaluate whether we are running on
- a uClinux or normal Linux target (see m68k_linux_get_sigtramp_info). */
+ /* Record that we will need to re-evaluate whether we are running on a
+ uClinux or normal GNU/Linux target (see m68k_linux_get_sigtramp_info). */
target_is_uclinux = -1;
}
@@ -227,7 +227,7 @@ m68k_linux_get_sigtramp_info (struct frame_info *next_frame)
if (target_is_uclinux == -1)
{
/* Determine whether we are running on a uClinux or normal Linux
target so we can use the correct sigcontext layouts. */
CORE_ADDR dummy;
@@ -227,7 +227,7 @@ m68k_linux_get_sigtramp_info (struct frame_info *next_frame)
if (target_is_uclinux == -1)
{
- /* Determine whether we are running on a uClinux or normal Linux
+ /* Determine whether we are running on a uClinux or normal GNU/Linux
target so we can use the correct sigcontext layouts. */
CORE_ADDR dummy;